==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="49"/>
        <source>WildMidi Plugin</source>
        <translation>ВајлдМиди прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="54"/>
        <source>Midi Files</source>
        <translation>Миди фајлови</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>О ВајлдМиди прикључку</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Кумп ВајлдМиди прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Користи WildMidi библиотеку за пуштање миди фајлова</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Поставке ВајлдМиди прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Подешавање инструмената: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Узорковање:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Побољшано преузорковање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Одјекивање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="49"/>
        <source>WildMidi Plugin</source>
        <translation>ВајлдМиди прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="54"/>
        <source>Midi Files</source>
        <translation>Миди фајлови</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="105"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>О ВајлдМиди прикључку</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Кумп ВајлдМиди прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Користи WildMidi библиотеку за пуштање миди фајлова</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WildMidiSettingsDialog</name>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation type="unfinished">Поставке ВајлдМиди прикључка</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation type="unfinished">Подешавање инструмената: </translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation type="unfinished">Узорковање:</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation type="unfinished">Побољшано преузорковање</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation type="unfinished">Одјекивање</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation type="unfinished">44100 Hz</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation type="unfinished">48000 Hz</translation>
    </message>
</context>
</TS>
